from distutils.core import setup

setup(
        name = 'nester_cmack',
        version = '1.2.0',
        py_modules = ['nester'],
        author = 'cmack',
        author_email = 'cmwebmail@gmail.com',
        url = 'http://www.cxm.com',
        description = 'A simple printer of nested lists'
        )
